#!/bin/bash
## -- FILE ------------------------------------------------------------------
## name       : bouncycastle-to-maven-layout.sh
## project    : intelliCard: MobileKeyStore
## created    : Leon Poyyayil - 2013-08-01
## language   : Linux shell script
## environment: GNU bash
## copyright  : (c) 2013 by intelliCard AG, Switzerland
## license    : this is corporate property of intelliCard AG
## --------------------------------------------------------------------------

# this script is based on the use-maven-layout.sh script from spongycastle
# but cleaned up and enhanced to support later versions than 1.47 and to
# properly function with filenames that contain spaces.


function move_file {
    # echo Moving $1 to $2
    mkdir -p `dirname "$2"`
    mv "$1" "$2"
}

function move_files {
    if [ -d "$1" ]; then
        echo "  $1/**/*.* => $2"
        find "$1" -type f -print0 | while read -d '' -r FILENAME
        do
            NEWFILENAME=`echo "$FILENAME" | sed -e "s,$1,$2,"`
            move_file "$FILENAME" "$NEWFILENAME"
        done
    fi
}

function move_files_of_type {
    if [ -d "$1" ]; then
        echo "  $1/**/*.$3 => $2"
        find "$1" -type f -name "*.$3" -print0 | while read -d '' -r FILENAME
        do
            NEWFILENAME=`echo "$FILENAME" | sed -e "s,$1,$2,"`
            move_file "$FILENAME" "$NEWFILENAME"
        done
    fi
}

function transplant_package {
    testmodule=bc-test
    module=$1
    pkg=$2
    echo "- module: $module / package: $pkg"

    for filetype in "java" "html"
    do
        move_files_of_type crypto/src/$pkg $module/src/main/java/$pkg $filetype
    done
    move_files crypto/src/$pkg $module/src/main/resources/$pkg

    echo "- module: $testmodule / package: $pkg"
    for filetype in "java" "html"
    do
        move_files_of_type crypto/test/src/$pkg $testmodule/src/test/java/$pkg $filetype
    done
    move_files crypto/test/src/$pkg $testmodule/src/test/resources/$pkg
    move_files crypto/test/data/$pkg $testmodule/src/test/resources/$pkg
}

function transplant_packages {
    module=$1
    for package in ${@:2}
    do
        transplant_package $module org/bouncycastle/$package
    done
}

echo "- module: bc-bzip2 / package: org/bouncycastle/apache/bzip2"
move_files crypto/bzip2/src         bc-bzip2/src/main/java

transplant_package  bc-mail  org/bouncycastle/mail
transplant_packages bc-pg    {openpgp,bcpg}
transplant_packages bc-pkix  {cert,cms,dvcs,eac,pkcs,mozilla,operator,openssl,tsp,voms}
transplant_packages bc-prov  {i18n,jcajce,jce,ocsp,pqc,x509}
transplant_package  bc-light org/bouncycastle

echo "- module: bc-test / test data"
move_files crypto/test/data/cmp     bc-test/src/test/resources/cmp
move_files crypto/test/data/hc-256  bc-test/src/test/resources/hc-256
move_files crypto/test/data/PKITS   bc-test/src/test/resources/PKITS
move_files crypto/test/data/openpgp bc-test/src/test/resources/openpgp
move_files crypto/test/data/rfc4134 bc-test/src/test/resources/rfc4134
move_files crypto/test/data/scrypt  bc-test/src/test/resources/scrypt
move_files crypto/test/data/tls     bc-test/src/test/resources/tls

echo "- documentation"
mkdir -p doc
mv crypto/*.html doc

echo "- cleanup"
rm -rf crypto

## -- EOF -------------------------------------------------------------------
